==> haskell-monad-par-0.3.4.8-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-KusFSzfQ64ZKb2OBEqXCdc
key: monad-par-0.3.4.8-KusFSzfQ64ZKb2OBEqXCdc
license: BSD-3-Clause
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
author: Simon Marlow, Ryan Newton
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
abi: f925a59dfc6a490d0faf4b925e5e8e36
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-0.3.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-KusFSzfQ64ZKb2OBEqXCdc
depends:
    base-4.11.1.0 abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
    abstract-deque-0.3-LkeWHH7SS5Y83xRhK9EdFK
    monad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf deepseq-1.4.3.0
    array-0.5.2.0 mwc-random-0.13.6.0-2hvpPCeD45r6gFYRqMiP8t
    containers-0.5.11.0 parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE
    mtl-2.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv=5a85b2fc79fc8de0f76069f2f5dd4dba
             abstract-deque-0.3-LkeWHH7SS5Y83xRhK9EdFK=65d98824ad6632b7d04f62e1d6381819
             monad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf=50c60a752a1eaff45e3db9a7fb2bfa87
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             mwc-random-0.13.6.0-2hvpPCeD45r6gFYRqMiP8t=7344a5c7a09b43c4769d3fcfaa13b8fc
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             parallel-3.2.1.1-7VRdiJcVWj8BvjtM2xssyE=b5c7268b9b5d05fd127858174b9c4c3a
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-par-0.3.4.8-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-monad-par.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: monad-par
version: 0.3.4.8
id: monad-par-0.3.4.8-9XTTCGkAp3w6ewjs82zoVb
key: monad-par-0.3.4.8-9XTTCGkAp3w6ewjs82zoVb
license: BSD-3-Clause
copyright: (c) Simon Marlow 2011
maintainer: Simon Marlow <marlowsd@gmail.com>, Ryan Newton <rrnewton@gmail.com>
author: Simon Marlow, Ryan Newton
stability: Experimental
homepage: https://github.com/simonmar/monad-par
synopsis: A library for parallel programming based on a monad
description:
    The '\''Par'\'' monad offers a simple API for parallel programming.  The
    library works for parallelising both pure and @IO@ computations,
    although only the pure version is deterministic.  The default
    implementation provides a work-stealing scheduler and supports
    forking tasks that are much lighter weight than IO-threads.
    .
    For complete documentation see "Control.Monad.Par".
    .
    Some examples of use can be found in the @examples/@ directory of
    the source package.
    .
    Other related packages:
    .
    * @abstract-par@ provides the type classes that abstract over different
    implementations of the @Par@ monad.
    .
    * @monad-par-extras@ provides extra combinators and monad transformers layered on top of
    the @Par@ monad.
    .
    Changes in 0.3.4 relative to 0.3:
    .
    * Fix bugs that cause "thread blocked indefinitely on MVar" crashes.
    .
    * Added "Control.Monad.Par.IO"
category: Control,Parallelism,Monads
abi: 60ed5c4a81b9561c130e1401ef7936fc
exposed: True
exposed-modules:
    Control.Monad.Par Control.Monad.Par.IO
    Control.Monad.Par.Scheds.Direct Control.Monad.Par.Scheds.Sparks
    Control.Monad.Par.Scheds.Trace
    Control.Monad.Par.Scheds.TraceInternal
hidden-modules: Control.Monad.Par.Scheds.DirectInternal
import-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-0.3.4.8
library-dirs: /usr/lib/ghc-8.4.3/site-local/monad-par-0.3.4.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/monad-par-0.3.4.8
hs-libraries: HSmonad-par-0.3.4.8-9XTTCGkAp3w6ewjs82zoVb
depends:
    base-4.11.1.0 abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv
    abstract-deque-0.3-LkeWHH7SS5Y83xRhK9EdFK
    monad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf deepseq-1.4.3.0
    array-0.5.2.0 mwc-random-0.13.6.0-2hvpPCeD45r6gFYRqMiP8t
    containers-0.5.11.0 parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS
    mtl-2.2.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             abstract-par-0.3.3-Ie3MD7O3orK6ZR8i7FuBEv=5a85b2fc79fc8de0f76069f2f5dd4dba
             abstract-deque-0.3-LkeWHH7SS5Y83xRhK9EdFK=65d98824ad6632b7d04f62e1d6381819
             monad-par-extras-0.3.3-9uJPRq6u2G7Dy6khFdWvSf=50c60a752a1eaff45e3db9a7fb2bfa87
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             mwc-random-0.13.6.0-2hvpPCeD45r6gFYRqMiP8t=7344a5c7a09b43c4769d3fcfaa13b8fc
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             parallel-3.2.2.0-E8M4t2NF24XDDNAVbYCukS=8817dbddef9879e3e8c45cfc95d59bc0
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
haddock-interfaces: /usr/share/doc/haskell-monad-par/html/monad-par.haddock
haddock-html: /usr/share/doc/haskell-monad-par/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
